@@ -111,7 +111,9 @@ class MonitorClient(AbstractClient):
 
 
     def CreateAlertRule(self, request):
-        """创建 Prometheus 告警规则
+        """创建 Prometheus 告警规则。
+
+        请注意，**告警对象和告警消息是 Prometheus Rule Annotations 的特殊字段，需要通过 annotations 来传递，对应的 Key 分别为summary/description**，，请参考 [Prometheus Rule更多配置请参考](https://prometheus.io/docs/prometheus/latest/configuration/alerting_rules/)。
 
         :param request: Request instance for CreateAlertRule.
         :type request: :class:`tencentcloud.monitor.v20180724.models.CreateAlertRuleRequest`
@@ -1361,7 +1363,9 @@ class MonitorClient(AbstractClient):
 
 
     def UpdateAlertRule(self, request):
-        """更新 Prometheus 的报警规则
+        """更新 Prometheus 的报警规则。
+
+        请注意，**告警对象和告警消息是 Prometheus Rule Annotations 的特殊字段，需要通过 annotations 来传递，对应的 Key 分别为summary/description**，，请参考 [Prometheus Rule更多配置请参考](https://prometheus.io/docs/prometheus/latest/configuration/alerting_rules/)。
 
         :param request: Request instance for UpdateAlertRule.
         :type request: :class:`tencentcloud.monitor.v20180724.models.UpdateAlertRuleRequest`
